from setuptools import setup, find_packages

setup(
    name="openswarm-os",
    version="0.1.0",
    author="Ted Ward",
    author_email="ted@tedward.net",
    description="The Unkillable, Local-First AI Agent Operating System.",
    long_description="# OpenSwarm\n\nAuthentication reserved. Full release coming soon.",
    long_description_content_type="text/markdown",
    url="https://github.com/openswarm-os/openswarm",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.9",
)
